Module db

Module db 

Functions

batch_insert_gtdb_tree
Inserts GTDB tree data into the specified table in batch, ignoring conflicts.
batch_insert_taxonomy
Inserts taxonomy data into the specified table in batch, ignoring conflicts.
create_genome_taxonomy_table
create_gtdb_tree_tables
create_tables
update_gtdb_tree_species
base genome_taxonomy table update gtdb_tree_{} table species gtdb_tree_{} gta table left join genome_taxonomy gt table on gt.node == gta.name update gta.species = gt.parent