Functions
- batch_
insert_ gtdb_ tree - Inserts GTDB tree data into the specified table in batch, ignoring conflicts.
- batch_
insert_ taxonomy - Inserts taxonomy data into the specified table in batch, ignoring conflicts.
- create_
genome_ taxonomy_ table - create_
gtdb_ tree_ tables - create_
tables - update_
gtdb_ tree_ species - base genome_taxonomy table update gtdb_tree_{} table species gtdb_tree_{} gta table left join genome_taxonomy gt table on gt.node == gta.name update gta.species = gt.parent